import org.faceless.graph2.*;
import java.awt.Color;
import java.awt.Paint;
import java.io.FileOutputStream;
import java.io.IOException;

public class PieGraphExample
{
    public static void main (String args[]) throws IOException
    {
        // Set up slice colors
        Color chocolateFactory = new Color(72,201,47);
        Color weddingCrashers = new Color(251,163,49);
        Color fantasticFour = new Color(250,123,213);
        Color island = Color.CYAN;
        Color badNewBears = Color.YELLOW;
        Color warWorlds = new Color(188,129,226);
        Color hustleFlow = new Color(252,47,110);
        Color devilsRejects = new Color(250,206,73);
        Color batmanBegins = new Color(124,124,255);
        Color marchPenguins = Color.LIGHT_GRAY;
        
        // Create the pie graph and add the data
        //
        PieGraph graph = new PieGraph();
        graph.set("Charlie and the Chocolate Factory", 28.3);
        graph.set("Wedding Crashers", 26.2);
        graph.set("Fantastic Four", 12.3);
        graph.set("The Island", 12.1);
        graph.set("The Bad News Bears", 11.5);
        graph.set("War of the Worlds", 8.8);
        graph.set("Hustle and Flow", 8.1);
        graph.set("The Devil's Rejects", 7);
        graph.set("Batman Begins", 4.7);
        graph.set("March of the Penguins", 4.3);
        
        // Set labels on each slice of the pie
        //
        TextStyle labelstyle = new TextStyle("Default",10,Color.BLACK);
        graph.setLabel ("Charlie and the Chocolate Factory", new Text("$28.5M", labelstyle), 0.9);
        graph.setLabel ("Wedding Crashers", new Text("$26.2M", labelstyle), 0.9);
        graph.setLabel ("Fantastic Four", new Text("$12.3M", labelstyle), 0.9);
        graph.setLabel ("The Island", new Text("$12.1M", labelstyle), 0.9);
        graph.setLabel ("The Bad News Bears", new Text("$11.5M", labelstyle), 0.9);
        graph.setLabel ("War of the Worlds", new Text("$8.8M", labelstyle), 0.9);
        graph.setLabel ("Hustle and Flow", new Text("$8.1M", labelstyle), 0.9);
        graph.setLabel ("The Devil's Rejects", new Text("$7M", labelstyle), 0.9);
        graph.setLabel ("Batman Begins", new Text("$4.7M", labelstyle), 0.9);
        graph.setLabel ("March of the Penguins", new Text("$4.3M", labelstyle), 0.9);

        // Set some other options
        //
        graph.setDefaultColors(new Paint[] {chocolateFactory,weddingCrashers,fantasticFour,island,badNewBears,warWorlds,hustleFlow,devilsRejects,batmanBegins,marchPenguins});
        graph.setYRotation(-30);
        graph.setZRotation(-10);
        graph.setDepth(30);

        // Add a title
        //
	graph.addText("Weekend Box Office Figures 22-24 July, 2005", new TextStyle("Default", 22, Color.red, Align.CENTER));
        graph.addText("North American Theatres", new TextStyle("Default", 18, Color.black, Align.CENTER));
        
        // Add a key
        //
        Key key = new Key(new Style(Color.WHITE));
        TextStyle ts = new TextStyle("Arial", 12, Color.BLACK);
        Marker m1 = new Marker("square",12);
        m1.setStyle (new Style(chocolateFactory));
        key.addCustom(m1, "Charlie and the Chocolate Factory", ts);
        Marker m2 = new Marker("square",12);
        m2.setStyle (new Style(weddingCrashers));
        key.addCustom(m2, "Wedding Crashers", ts);
        Marker m3 = new Marker("square",12);
        m3.setStyle (new Style(fantasticFour));
        key.addCustom(m3, "Fantastic Four", ts);
        Marker m4 = new Marker("square",12);
        m4.setStyle (new Style(island));
        key.addCustom(m4, "The Island", ts);
        Marker m5 = new Marker("square",12);
        m5.setStyle (new Style(badNewBears));
        key.addCustom(m5, "The Bad News Bears", ts);
        Marker m6 = new Marker("square",12);
        m6.setStyle (new Style(warWorlds));
        key.addCustom(m6, "War of the Worlds", ts);
        Marker m7 = new Marker("square",12);
        m7.setStyle (new Style(hustleFlow));
        key.addCustom(m7, "Hustle and Flow", ts);
        Marker m8 = new Marker("square",12);
        m8.setStyle (new Style(devilsRejects));
        key.addCustom(m8, "The Devil's Rejects", ts);
        Marker m9 = new Marker("square",12);
        m9.setStyle (new Style(batmanBegins));
        key.addCustom(m9, "Batman Begins", ts);
        Marker m10 = new Marker("square",12);
        m10.setStyle (new Style(marchPenguins));
        key.addCustom(m10, "March of the Penguins", ts);
        key.setMaxWidth(500);
        graph.addKey(key, Align.BOTTOM);
        
        // Write the file
        //
	ImageOutput image = new ImageOutput(500, 500);
	graph.draw(image);
	FileOutputStream out = new FileOutputStream("PieGraphExample.png");
	image.writePNG(out, 0);
        out.close();
    }
}